@@ -2,6 +2,7 @@ import doctest
 from textops import *
 import os
 import json
+import sys
 
 modules = [ 'textops.base',
             'textops.ops.cast',
@@ -18,12 +19,18 @@ files = [ 'docs/intro.rst' ]
 failed = 0
 tested = 0
 
+REPORT = doctest.REPORT_NDIFF
+if len(sys.argv) > 1 and sys.argv[1] == '-c':
+    # report where there 2 entire blocks with ! to see differences
+    # useful to cut&paste wanted result
+    REPORT = doctest.REPORT_CDIFF
+
 print '=' * 60
 
 for m in modules:
     print 'Testing %s ...' % m
     mod = __import__(m,fromlist=[''])
-    fcount, tcount = doctest.testmod(mod,globs=globals(),optionflags=doctest.REPORT_NDIFF)
+    fcount, tcount = doctest.testmod(mod,globs=globals(),optionflags=REPORT)
     failed += fcount
     tested += tcount
 
@@ -31,7 +38,7 @@ base_dir = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
 for f in files:
     print 'Testing %s ...' % f
     path = os.path.join(base_dir,f)
-    fcount, tcount = doctest.testfile(path,False,globs=globals(),optionflags=doctest.REPORT_NDIFF)
+    fcount, tcount = doctest.testfile(path,False,globs=globals(),optionflags=REPORT)
     failed += fcount
     tested += tcount
 
